<h1 align="center">
  <br>
  <a href="https://discord.gg/54E3j7eyDV"><img src="https://pysc.cf/static/images/img-1.jpg" width="600"></a>
  <br>
</h1>


### What is this lib?
Unofficial Amino API written in Python to easily connect Amino servers

### How to install?
`pip install SAmino`
- **FOCUS!:** type `SAmino` **Not** `Amino`



**CR**: Pysc Overall
